Conditionals and recursion
::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   TheModulusOperator.rst
   ConditionalExecution.rst
   AlternativeExecution.rst
   ChainedConditionals.rst
   NestedConditionals.rst
   TheReturnStatement.rst
   Recursion.rst
   InfiniteRecursion.rst
   StackDiagrams.rst
   Glossary.rst
   Exercises.rst
   MixedUpCode.rst
   activeCode.rst
